/*

  This file is a part of MeanWalker, a library which provides utilities to
  sample from probability distributions using methods like the 
  Metropilis-Hastings algorithm and Goodman-Weare algorithm.

  Copyright (C) 2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "goodmanwearehistogrambuilder.h"
#include <iostream>

namespace meanwalker
{

GoodmanWeareHistogramBuilder::GoodmanWeareHistogramBuilder(RandomNumberGenerator *pRndGen) : HistogramBuilderTemplate<GoodmanWeareWalkers>(pRndGen)
{
}

GoodmanWeareHistogramBuilder::~GoodmanWeareHistogramBuilder()
{
}

bool GoodmanWeareHistogramBuilder::init(Function *pProbFunction, const double *pStartCoordCenter, double startCoordRadius,
		  size_t numBins, const double *pHistMinCoords, const double *pHistMaxCoords, 
		  double a, int Nwalkers)
{
	bool retValue;

	if (pHistMinCoords == 0 || pHistMaxCoords == 0)
		retValue = initDelayed(pProbFunction->getDimension(), numBins);
	else
		retValue = initNormal(pHistMinCoords, pHistMaxCoords, pProbFunction->getDimension(), numBins);

	if (!retValue)
		return false;

	if (!GoodmanWeareWalkers::init(pProbFunction, pStartCoordCenter, startCoordRadius, a, Nwalkers))
	{
		destroy();
		return false;
	}
	
	return true;
}

bool GoodmanWeareHistogramBuilder::init(Function *pProbFunction, const double *pStartCoordCenter, const double *pStartCoordRadii,
		  size_t numBins, const double *pHistMinCoords, const double *pHistMaxCoords, 
		  double a, int Nwalkers)
{
	bool retValue;

	if (pHistMinCoords == 0 || pHistMaxCoords == 0)
		retValue = initDelayed(pProbFunction->getDimension(), numBins);
	else
		retValue = initNormal(pHistMinCoords, pHistMaxCoords, pProbFunction->getDimension(), numBins);

	if (!retValue)
		return false;

	if (!GoodmanWeareWalkers::init(pProbFunction, pStartCoordCenter, pStartCoordRadii, a, Nwalkers))
	{
		destroy();
		return false;
	}
	
	return true;
}

} // end namespace   
